@@ -72,6 +72,9 @@
 #include <utils.h>
 #include <QMimeDatabase>
 
+#ifdef WITH_FEEDBACK
+#include "plasmauserfeedback.h"
+#endif
 #include "discoversettings.h"
 
 class CachedNetworkAccessManagerFactory : public QQmlNetworkAccessManagerFactory
@@ -93,7 +96,7 @@ public:
     }
 };
 
-DiscoverObject::DiscoverObject(CompactMode mode)
+DiscoverObject::DiscoverObject(CompactMode mode, const QVariantMap &initialProperties)
     : QObject()
     , m_engine(new QQmlApplicationEngine)
     , m_mode(mode)
@@ -111,13 +114,16 @@ DiscoverObject::DiscoverObject(CompactMode mode)
     qmlRegisterType<KConcatenateRowsProxyModel>("org.kde.discover.app", 1, 0, "KConcatenateRowsProxyModel");
     qmlRegisterType<FeaturedModel>("org.kde.discover.app", 1, 0, "FeaturedModel");
     qmlRegisterType<OurSortFilterProxyModel>("org.kde.discover.app", 1, 0, "QSortFilterProxyModel");
-
+#ifdef WITH_FEEDBACK
+    qmlRegisterSingletonType<PlasmaUserFeedback>("org.kde.discover.app", 1, 0, "UserFeedbackSettings", [](QQmlEngine*, QJSEngine*) -> QObject* { return new PlasmaUserFeedback(KSharedConfig::openConfig(QStringLiteral("PlasmaUserFeedback"), KConfig::NoGlobals)); });
+#endif
     qmlRegisterSingletonType<DiscoverSettings>("org.kde.discover.app", 1, 0, "DiscoverSettings", [](QQmlEngine*, QJSEngine*) -> QObject* {
             auto r = new DiscoverSettings;
             connect(r, &DiscoverSettings::installedPageSortingChanged, r, &DiscoverSettings::save);
             connect(r, &DiscoverSettings::appsListPageSortingChanged, r, &DiscoverSettings::save);
             return r;
         });
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     qmlRegisterType<QQuickView>();
     qmlRegisterType<QActionGroup>();
     qmlRegisterType<QAction>();
@@ -125,6 +131,16 @@ DiscoverObject::DiscoverObject(CompactMode mode)
     qmlRegisterType<KAboutData>();
     qmlRegisterType<KAboutLicense>();
     qmlRegisterType<KAboutPerson>();
+#else
+    qmlRegisterAnonymousType<QQuickView>("org.kde.discover.app", 1);
+    qmlRegisterAnonymousType<QActionGroup>("org.kde.discover.app", 1);
+    qmlRegisterAnonymousType<QAction>("org.kde.discover.app", 1);
+
+    qmlRegisterAnonymousType<KAboutData>("org.kde.discover.app", 1);
+    qmlRegisterAnonymousType<KAboutLicense>("org.kde.discover.app", 1);
+    qmlRegisterAnonymousType<KAboutPerson>("org.kde.discover.app", 1);
+#endif
+
     qmlRegisterUncreatableType<DiscoverObject>("org.kde.discover.app", 1, 0, "DiscoverMainWindow", QStringLiteral("don't do that"));
     setupActions();
 
@@ -134,6 +150,9 @@ DiscoverObject::DiscoverObject(CompactMode mode)
     plugin->initializeEngine(m_engine, uri);
     plugin->registerTypes(uri);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    m_engine->setInitialProperties(initialProperties);
+#endif
     m_engine->rootContext()->setContextProperty(QStringLiteral("app"), this);
     m_engine->rootContext()->setContextProperty(QStringLiteral("discoverAboutData"), QVariant::fromValue(KAboutData::applicationData()));
 
@@ -490,11 +509,6 @@ void DiscoverObject::showPassiveNotification(const QString& msg)
     });
 }
 
-void DiscoverObject::copyTextToClipboard(const QString& text)
-{
-    qGuiApp->clipboard()->setText(text);
-}
-
 void DiscoverObject::reboot()
 {
     QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
@@ -507,4 +521,9 @@ QRect DiscoverObject::initialGeometry() const
     return window.readEntry("geometry", QRect());
 }
 
+QString DiscoverObject::describeSources() const
+{
+    return rootObject()->property("describeSources").toString();
+}
+
 #include "DiscoverObject.moc"
