@@ -41,7 +41,7 @@ class DiscoverObject : public QObject
         enum CompactMode { Auto, Compact, Full };
         Q_ENUM(CompactMode)
 
-        explicit DiscoverObject(CompactMode mode);
+        explicit DiscoverObject(CompactMode mode, const QVariantMap &initialProperties);
         ~DiscoverObject() override;
 
         QStringList modes() const;
@@ -62,6 +62,8 @@ class DiscoverObject : public QObject
         void showPassiveNotification(const QString &msg);
         QRect initialGeometry() const;
 
+        QString describeSources() const;
+
     public Q_SLOTS:
         void openApplication(const QUrl& app);
         void openMimeType(const QString& mime);
@@ -69,8 +71,6 @@ class DiscoverObject : public QObject
         void openMode(const QString& mode);
         void openLocalPackage(const QUrl &localfile);
 
-        void copyTextToClipboard(const QString &text);
-
         void reboot();
 
     private Q_SLOTS:
