@@ -186,7 +186,7 @@ void OdrsReviewsBackend::usefulnessSubmitted()
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
 
     if (reply->error() == QNetworkReply::NoError) {
-        qCWarning(LIBDISCOVER_LOG) << "Usefullness submitted";
+        qCWarning(LIBDISCOVER_LOG) << "Usefulness submitted";
     } else {
         qCWarning(LIBDISCOVER_LOG) << "Failed to submit usefulness: " << reply->errorString();
     }
@@ -195,7 +195,7 @@ void OdrsReviewsBackend::usefulnessSubmitted()
 
 QString OdrsReviewsBackend::userName() const
 {
-    return i18n("%1 (%2)", KUser().property(KUser::FullName).toString(), KUser().loginName());
+    return KUser().property(KUser::FullName).toString();
 }
 
 void OdrsReviewsBackend::submitReview(AbstractResource *res, const QString &summary, const QString &description, const QString &rating)
@@ -290,7 +290,7 @@ void OdrsReviewsBackend::parseReviews(const QJsonDocument &document, AbstractRes
                 const int usefulFavorable = review.value(QStringLiteral("karma_up")).toInt();
                 const int usefulTotal = review.value(QStringLiteral("karma_down")).toInt() + usefulFavorable;
                 QDateTime dateTime;
-                dateTime.setTime_t(review.value(QStringLiteral("date_created")).toInt());
+                dateTime.setSecsSinceEpoch(review.value(QStringLiteral("date_created")).toInt());
                 ReviewPtr r(new Review(review.value(QStringLiteral("app_id")).toString(), resource->packageName(),
                                        review.value(QStringLiteral("locale")).toString(), review.value(QStringLiteral("summary")).toString(),
                                        review.value(QStringLiteral("description")).toString(), review.value(QStringLiteral("user_display")).toString(),
